import { stackedAreaChart } from './stackedAreaChart';

const svg = d3.select(document.body).append('svg');
const gigatons = str => (+str) / 1000;

var parseRow = d => {
  d.Year = new Date(d.Year);
  d.Gas = gigatons(d.Gas);
  d.Liquids = gigatons(d.Liquids);
  d.Solids = gigatons(d.Solids);
  d['Cement Production'] = gigatons(d['Cement Production']);
  d['Gas Flaring'] = gigatons(d['Gas Flaring']);
  return d;
};
  
d3.csv('https://vizhub.com/curran/datasets/global-co2-emissions.csv', parseRow, data => {
  data = data.filter(d => d.Year > new Date("1790"));
  const render = () => {
    const width = document.body.clientWidth;
    const height = document.body.clientHeight;
    
    svg.attr('width', width).attr('height', height);
    
    let g = svg.selectAll('g').data([null]);
    g = g.enter().append('g').merge(g);
    
    stackedAreaChart(g, {
      data,
      keys: ["Gas", "Liquids", "Solids", "Cement Production", "Gas Flaring"],
      width,
      height,
      xValue: d => d.Year,
      colorScale: d3.scaleOrdinal(d3.schemeDark2),
      margin: { top: 10, right: 20, bottom: 40, left: 57 },
      yAxisTitle: 'CO2 Emissions (Gigatons per Year)',
      yAxisTitleOffset: -26
    });
  };
  render();
  
  window.addEventListener('resize', render);
});